@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 
 # typedload
-# Copyright (C) 2020-2024 Salvo "LtWorf" Tomaselli
+# Copyright (C) 2020-2026 Salvo "LtWorf" Tomaselli
 #
 # typedload is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@ import argparse
 from datetime import datetime
 from uuid import UUID
 import json
-from typing import *
+from typing import Any, NamedTuple
 import urllib.request
 
 import typedload
@@ -40,8 +40,8 @@ import typedload
 
 class CommandLine(NamedTuple):
     full: bool
-    project: Optional[str]
-    username: Optional[str]
+    project: str | None
+    username: str | None
 
     def get_url(self) -> str:
         if self.username is None and self.project is None:
@@ -86,7 +86,7 @@ class Release(NamedTuple):
     created_at: datetime
     published_at: datetime
     author: User
-    assets: List[Asset]
+    assets: list[Asset]
 
 
 def get_data(args: CommandLine) -> Any:
@@ -98,14 +98,14 @@ def get_data(args: CommandLine) -> Any:
         return json.load(f)
 
 
-def print_report(data: List[Release], args: CommandLine):
+def print_report(data: list[Release], args: CommandLine) -> None:
     for i in data:
         if i.draft or i.prerelease:
             continue
-        print('Release:', i.name, end=' ')
+        print(f'Release: "{i.name}"', end=' ')
 
         if args.full:
-            print('Created by:', i.author.login, 'on:', i.created_at)
+            print(f'Created by: {i.author.login} on: {i.created_at}')
         else:
             print()
 
@@ -114,8 +114,8 @@ def print_report(data: List[Release], args: CommandLine):
                 print('\t%d\t%s' % (asset.download_count, asset.name))
 
 
-def main():
-    parser = argparse.ArgumentParser()
+def main() -> None:
+    parser = argparse.ArgumentParser(description='Query the codeberg API to list the releases and download counts of projects')
     parser.add_argument('-u', '--username', help='The username to query')
     parser.add_argument('-p', '--project', help='The project to query')
     parser.add_argument('-f', '--full', help='Print the full report', action='store_true')
@@ -124,12 +124,10 @@ def main():
     args = typedload.load(parser.parse_args(), CommandLine)
     data = get_data(args)
 
-    # Github returns dates like this "2016-08-23T18:26:00Z", which are not supported by typedload
-    # So we make a custom handler for them.
     loader = typedload.dataloader.Loader()
 
     # We know what the API returns so we can load the json into typed data
-    typed_data = loader.load(data, List[Release])
+    typed_data = loader.load(data, list[Release])
     print_report(typed_data, args)
 
 
