@@ -1,5 +1,5 @@
 # typedload
-# Copyright (C) 2018-2025 Salvo "LtWorf" Tomaselli
+# Copyright (C) 2018-2026 Salvo "LtWorf" Tomaselli
 #
 # typedload is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@ from .test_typechecks import *
 from .test_datetime import *
 from .test_literal import *
 from .test_typeddict import *
-from .test_orunion import *
+from .test_moretypes import *
 
 if sys.version_info.minor >= 12:
     from .test_typealias import *
