@@ -45,10 +45,6 @@ class TestTypeddictLoad(unittest.TestCase):
 
     def test_mixed_totality(self):
 
-        if sys.version_info.minor == 8:
-            # This only works from 3.9
-            return
-
         with self.assertRaises(TypeError):
             load({}, C)
         assert load({'val': 'a'}, C) == {'val': 'a'}
@@ -184,3 +180,24 @@ if sys.version_info.minor >= 11:
                 load({}, B)
             assert load({'a': 1}, B) == {'a': 1}
             assert load({'a': 1, 'd':12}, B) == {'a': 1, 'd': 12}
+
+if sys.version_info.minor >= 13:
+
+    from typing import ReadOnly
+
+    class TestReadOnly(unittest.TestCase):
+
+        def test_load(self):
+
+            class A(TypedDict):
+                i: ReadOnly[int]
+            q=load({'i': 1}, A)
+            assert load({'i': 1}, A) == {'i': 1}
+
+        def test_loadwithannotationnesting(self):
+
+            class A(TypedDict, total=True):
+                i: ReadOnly[NotRequired[int]]
+
+            assert load({}, A) == {}
+            assert load({'i': 1}, A) == {'i': 1}
